# Generated by Django 5.2.11 on 2026-02-23 20:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("keysmith", "0001_initial"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="token",
            name="hint",
        ),
        migrations.AlterField(
            model_name="tokenauditlog",
            name="action",
            field=models.CharField(
                choices=[
                    ("auth_success", "Authentication Success"),
                    ("auth_failed", "Authentication Failed"),
                    ("created", "Token Created"),
                    ("revoked", "Token Revoked"),
                    ("rotated", "Token Rotated"),
                ],
                max_length=64,
            ),
        ),
    ]
