{% extends "admin/base_site.html" %}
{% load i18n %}

{% block breadcrumbs %}
<div class="breadcrumbs">
  <a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
  &rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
  &rsaquo; <a href="{% url 'admin:keysmith_token_changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
  &rsaquo; {% translate 'Token created' %}
</div>
{% endblock %}

{% block content_title %}{% endblock %}

{% block content %}
<div id="content-main">
  <p><strong>Copy token now.</strong> This value is shown only once.</p>

  <fieldset class="module aligned">
    <div class="form-row">
      <div>
        <label>Token</label>
        <textarea readonly rows="4" style="width: 100%; font-family: monospace;">{{ raw_token }}</textarea>
      </div>
    </div>
  </fieldset>

  <div class="submit-row">
    <a class="button" href="{% url 'admin:keysmith_token_change' token.pk %}">Go to token details</a>
    <a class="button" href="{% url 'admin:keysmith_token_changelist' %}">Back to tokens</a>
  </div>
</div>
{% endblock %}
